@@ -12,7 +12,7 @@ from jsii.python import classproperty
 import aws_cdk.aws_certificatemanager
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
-import aws_cdk.aws_route53
+import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
 import aws_cdk.cdk
 __all__ = []
